ntfy_api_response = {
    "id": "jBXrDQF4e8ab",
    "time": 1681939903,
    "expires": 1681983103,
    "event": "message",
    "topic": "frigate-test",
    "title": "goat entered lawn at 2023-04-06 14:31:46.638857+00:00",
    "message": "goat was in barn before",
    "click": "https://frigate.local/events?camera=cam-testdrive\\u0026label=goat\\u0026zone=lawn",
}


ntfy_api_response = {
    "id": "jBXrDQF4e8ab",
    "time": 1681939903,
    "expires": 1681983103,
    "event": "message",
    "topic": "frigate-test",
    "title": "goat entered lawn at 2023-04-06 14:31:46.638857+00:00",
    "message": "goat was in barn before",
    "click": "https://frigate.local/events?camera=cam-testdrive\\u0026label=goat\\u0026zone=lawn",
    "attachment": {
        "name": "mqttwarn-frigate-cam-testdrive-goat.png",
        "type": "image/png",
        "size": 283595,
        "expires": 1681950703,
        "url": "http://localhost:5555/file/jBXrDQF4e8ab.png",
    },
}


ntfy_api_response = {
    "id": "jBXrDQF4e8ab",
    "time": 1681939903,
    "expires": 1681983103,
    "event": "message",
    "topic": "frigate-test",
    "title": "goat entered lawn at 2023-04-06 14:31:46.638857+00:00",
    "message": "goat was in barn before",
    "click": "https://frigate.local/events?camera=cam-testdrive\\u0026label=goat\\u0026zone=lawn",
    "attachment": {
        "name": "mqttwarn-frigate-cam-testdrive-goat.png",
        "type": "image/png",
        "size": 283595,
        "expires": 1681950703,
        "url": "http://localhost:5555/file/jBXrDQF4e8ab.png",
    },
}
